@@ -65,8 +65,8 @@ def croshell(
         text = f"📄 Reading data from: {file_obj.name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
     else:  # if nothing is specified, then run in interactive mode.
-        text = "⌨️  Entering interactive mode"
-        console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
+        # text = "⌨️  Entering interactive mode"
+        # console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
         # from machineconfig.scripts.python.croshell import InteractiveShell
         # InteractiveShell().run()
         # return None
@@ -124,10 +124,13 @@ def croshell(
             # if writing fails, fall back to the default nb_target already set
             pass
     if visidata:
-        fire_line = f"uv run --with visidata,pyarrow vd {str(file_obj)}"
+        if file_obj.suffix == ".json":
+            fire_line = f"uv run --with visidata vd {str(file_obj)}"
+        else:
+            fire_line = f"uv run --with visidata,pyarrow vd {str(file_obj)}"
     elif marimo:
         if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--with marimo --project "{str(Path.home().joinpath("code/machineconfig"))}" """
-        else: requirements = """--with "marimo,machineconfig[plot]>=6.52" """
+        else: requirements = """--with "marimo,machineconfig[plot]>=6.57" """
         fire_line = f"""
 cd {str(pyfile.parent)}
 uv run --with "marimo" marimo convert {pyfile.name} -o marimo_nb.py
@@ -135,14 +138,14 @@ uv run  {requirements} marimo edit --host 0.0.0.0 marimo_nb.py
 """
     elif jupyter:
         if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" --with jupyterlab """
-        else: requirements = """--with "machineconfig[plot]>=6.52" """
+        else: requirements = """--with "machineconfig[plot]>=6.57" """
         fire_line = f"uv run {requirements} jupyter-lab {str(nb_target)}"
     elif vscode:
         fire_line = f"""
 cd {str(pyfile.parent)}
 uv init --python 3.14
 uv venv
-uv add "machineconfig[plot]>=6.52"
+uv add "machineconfig[plot]>=6.57"
 # code serve-web
 code --new-window {str(pyfile)}
 """
@@ -150,7 +153,7 @@ code --new-window {str(pyfile)}
         if interpreter == "ipython": profile = f" --profile {ipython_profile} --no-banner"
         else: profile = ""
         if Path.home().joinpath("code/machineconfig").exists(): ve_line = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" """
-        else: ve_line = """--with "machineconfig[plot]>=6.52" """
+        else: ve_line = """--with "machineconfig[plot]>=6.57" """
         # ve_path_maybe, ipython_profile_maybe = get_ve_path_and_ipython_profile(Path.cwd())
         # --python 3.14
         fire_line = f"uv run {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
