@@ -1,10 +1,10 @@
+
 from pathlib import Path
 from typing import Callable, Optional, Union, Any, Protocol, List, TypeVar
 import logging
 import time
 from datetime import datetime, timezone, timedelta
 from machineconfig.utils.io import from_pickle
-from machineconfig.utils.path_extended import PathExtended
 
 
 class LoggerTemplate(Protocol):
@@ -147,7 +147,6 @@ class Scheduler:
 T2 = TypeVar("T2")
 def to_pickle(obj: Any, path: Path) -> None:
     import pickle
-    path.parent.mkdir(parents=True, exist_ok=True)
     path.write_bytes(pickle.dumps(obj))
 
 
@@ -160,45 +159,37 @@ class CacheMemory[T]():
         self.time_produced = datetime.now()
         self.logger = logger
         self.expire = expire
-        self.name = name if isinstance(name, str) else str(self.source_func)
-        self.last_call_is_fresh = False
-
+        self.name = name if isinstance(name, str) else self.source_func.__name__
     @property
     def age(self) -> timedelta:
         return datetime.now() - self.time_produced
 
     def __call__(self, fresh: bool = False) -> T:
-        self.last_call_is_fresh = False
         if fresh or not hasattr(self, "cache"):
-            if self.logger:
-                why = "There was an explicit fresh order." if fresh else "Previous cache never existed."
-                self.logger.warning(f"""
-🆕 ════════════════════ NEW CACHE ════════════════════
-🔄 {self.name} cache: Populating fresh cache from source func
-ℹ️  Reason: {why}
-════════════════════════════════════════════════════════""")
+            why = "There was an explicit fresh order." if fresh else "Previous cache never existed."
+            t0 = time.time()
+            self.logger.warning(f"""
+🆕 ════════════════════ NEW {self.name} CACHE ════════════════════
+ℹ️ Reason: {why}""")
             self.cache = self.source_func()
-            self.last_call_is_fresh = True
+            self.logger.warning(f"⏱️  Cache population took {time.time() - t0:.2f} seconds.")
             self.time_produced = datetime.now()
         else:
             age = self.age
             if age > self.expire:
-                if self.logger:
-                    self.logger.warning(f"""
+                self.logger.warning(f"""
 🔄 ════════════════════ CACHE UPDATE ════════════════════
 ⚠️  {self.name} cache: Updating cache from source func
-⏱️  Age = {age} > {self.expire}
-════════════════════════════════════════════════════════""")
+⏱️  Age = {age} > {self.expire}""")
+                t0 = time.time()
                 self.cache = self.source_func()
-                self.last_call_is_fresh = True
+                self.logger.warning(f"⏱️  Cache population took {time.time() - t0:.2f} seconds.")
                 self.time_produced = datetime.now()
             else:
-                if self.logger:
-                    self.logger.warning(f"""
+                self.logger.warning(f"""
 ✅ ════════════════════ USING CACHE ════════════════════
 📦 {self.name} cache: Using cached values
-⏱️  Lag = {age}
-════════════════════════════════════════════════════════""")
+⏱️  Lag = {age}""")
         return self.cache
 
     @staticmethod
@@ -215,57 +206,51 @@ class Cache[T]():  # This class helps to accelrate access to latest data coming
     ) -> None:
         self.cache: T
         self.source_func = source_func  # function which when called returns a fresh object to be frozen.
-        self.path: PathExtended = PathExtended(path)
+        self.path: Path = path
+        _ = self.path.parent.mkdir(parents=True, exist_ok=True)
         self.time_produced = datetime.now()  # if path is None else
         self.save = saver
         self.reader = reader
         self.logger = logger
         self.expire = expire
-        self.name = name if isinstance(name, str) else str(self.source_func)
-        self.last_call_is_fresh = False
-
+        self.name = name if isinstance(name, str) else self.source_func.__name__
     @property
     def age(self):
         """Throws AttributeError if called before cache is populated and path doesn't exists"""
         return datetime.now() - self.time_produced
     def __call__(self, fresh: bool = False) -> T:
-        self.last_call_is_fresh = False
         if fresh or not hasattr(self, "cache"):  # populate cache for the first time
             if not fresh and self.path.exists():
                 age = datetime.now() - datetime.fromtimestamp(self.path.stat().st_mtime)
                 msg1 = f"""
 📦 ════════════════════ CACHE OPERATION ════════════════════
 🔄 {self.name} cache: Reading cached values from `{self.path}`
-⏱️  Lag = {age}
-════════════════════════════════════════════════════════════"""
+⏱️  Lag = {age}"""
                 try:
                     self.cache = self.reader(self.path)
                 except Exception as ex:
-                    if self.logger:
-                        msg2 = f"""
+                    msg2 = f"""
 ❌ ════════════════════ CACHE ERROR ════════════════════
 ⚠️  {self.name} cache: Cache file is corrupted
-🔍 Error: {ex}
-════════════════════════════════════════════════════════"""
-                        self.logger.warning(msg1 + msg2)
+🔍 Error: {ex}"""
+                    self.logger.warning(msg1 + msg2)
+                    t0 = time.time()
                     self.cache = self.source_func()
-                    self.last_call_is_fresh = True
+                    self.logger.warning(f"⏱️  Cache population took {time.time() - t0:.2f} seconds.")
                     self.time_produced = datetime.now()
-                    # if self.path is not None:
-                    #     self.save(self.cache, self.path)
+                    self.save(self.cache, self.path)
                     return self.cache
                 return self(fresh=False)  # may be the cache is old ==> check that by passing it through the logic again.
             else:
-                if self.logger:
-                    # Previous cache never existed or there was an explicit fresh order.
-                    why = "There was an explicit fresh order." if fresh else "Previous cache never existed or is corrupted."
-                    self.logger.warning(f"""
+                # Previous cache never existed or there was an explicit fresh order.
+                why = "There was an explicit fresh order." if fresh else "Previous cache never existed or is corrupted."
+                self.logger.warning(f"""
 🆕 ════════════════════ NEW CACHE ════════════════════
 🔄 {self.name} cache: Populating fresh cache from source func
-ℹ️  Reason: {why}
-════════════════════════════════════════════════════════""")
+ℹ️  Reason: {why}""")
+                t0 = time.time()
                 self.cache = self.source_func()  # fresh data.
-                self.last_call_is_fresh = True
+                self.logger.warning(f"⏱️  Cache population took {time.time() - t0:.2f} seconds.")
                 self.time_produced = datetime.now()
                 self.save(self.cache, self.path)
         else:  # cache exists
@@ -274,23 +259,20 @@ class Cache[T]():  # This class helps to accelrate access to latest data coming
             except AttributeError:  # path doesn't exist (may be deleted) ==> need to repopulate cache form source_func.
                 return self(fresh=True)
             if age > self.expire:
-                if self.logger:
-                    self.logger.warning(f"""
+                self.logger.warning(f"""
 🔄 ════════════════════ CACHE UPDATE ════════════════════
 ⚠️  {self.name} cache: Updating cache from source func
-⏱️  Age = {age} > {self.expire}
-════════════════════════════════════════════════════════""")
+⏱️  Age = {age} > {self.expire}""")
+                t0 = time.time()
                 self.cache = self.source_func()
-                self.last_call_is_fresh = True
+                self.logger.warning(f"⏱️  Cache population took {time.time() - t0:.2f} seconds.")
                 self.time_produced = datetime.now()
                 self.save(self.cache, self.path)
             else:
-                if self.logger:
-                    self.logger.warning(f"""
+                self.logger.warning(f"""
 ✅ ════════════════════ USING CACHE ════════════════════
 📦 {self.name} cache: Using cached values
-⏱️  Lag = {age}
-════════════════════════════════════════════════════════""")
+⏱️  Lag = {age}""")
         return self.cache
 
     @staticmethod
@@ -300,5 +282,4 @@ class Cache[T]():  # This class helps to accelrate access to latest data coming
         def decorator(source_func: Callable[[], T2]) -> Cache["T2"]:
             res = Cache(source_func=source_func, expire=expire, logger=logger, path=path, name=name, reader=reader, saver=saver)
             return res
-
         return decorator
